import sys
import typing


def preset_add(name: str = "", remove_active: bool = False):
    '''Add or remove a Safe Areas Preset 

    :param name: Name, Name of the preset, used to make the path name 
    :type name: str
    :param remove_active: remove_active 
    :type remove_active: bool
    '''

    pass
