import sys
import typing


class AddonPreferences:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Bone:
    basename = None
    ''''''

    bl_rna = None
    ''''''

    center = None
    ''''''

    children = None
    ''''''

    children_recursive = None
    ''''''

    children_recursive_basename = None
    ''''''

    id_data = None
    ''''''

    length = None
    ''''''

    parent_recursive = None
    ''''''

    vector = None
    ''''''

    x_axis = None
    ''''''

    y_axis = None
    ''''''

    z_axis = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def parent_index(self, parent_test):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def translate(self, vec):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class CompositorNode:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def is_registered_node_type(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def poll(self, ntree):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def update(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Context:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def copy(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class EditBone:
    basename = None
    ''''''

    bl_rna = None
    ''''''

    center = None
    ''''''

    children = None
    ''''''

    children_recursive = None
    ''''''

    children_recursive_basename = None
    ''''''

    id_data = None
    ''''''

    length = None
    ''''''

    parent_recursive = None
    ''''''

    vector = None
    ''''''

    x_axis = None
    ''''''

    y_axis = None
    ''''''

    z_axis = None
    ''''''

    def align_orientation(self, other):
        '''

        '''
        pass

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def parent_index(self, parent_test):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def transform(self, matrix, scale, roll):
        '''

        '''
        pass

    def translate(self, vec):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Group:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    users_dupli_group = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Header:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def append(self, draw_func):
        '''

        '''
        pass

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_extended(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def prepend(self, draw_func):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def remove(self, draw_func):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class KeyingSetInfo:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Library:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    users_id = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Macro:
    id_data = None
    ''''''

    order = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def define(self, opname):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Menu:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def append(self, draw_func):
        '''

        '''
        pass

    def as_pointer(self):
        '''

        '''
        pass

    def draw_collapsible(self, context, layout):
        '''

        '''
        pass

    def draw_preset(self, context):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_extended(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def prepend(self, draw_func):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def remove(self, draw_func):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Mesh:
    bl_rna = None
    ''''''

    cycles = None
    ''''''

    edge_keys = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def from_pydata(self, vertices, edges, faces):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class MeshEdge:
    id_data = None
    ''''''

    key = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class MeshPolygon:
    edge_keys = None
    ''''''

    id_data = None
    ''''''

    loop_indices = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class MeshTessFace:
    center = None
    ''''''

    edge_keys = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Node:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def is_registered_node_type(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def poll(self, ntree):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class NodeInternal:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def is_registered_node_type(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def poll(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class NodeSocket:
    id_data = None
    ''''''

    links = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class NodeSocketInterface:
    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class NodeTree:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Object:
    bl_rna = None
    ''''''

    children = None
    ''''''

    cycles = None
    ''''''

    cycles_visibility = None
    ''''''

    id_data = None
    ''''''

    users_group = None
    ''''''

    users_scene = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Operator:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    order = None
    ''''''

    def as_keywords(self, ignore):
        '''

        '''
        pass

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class OrderedDictMini:
    def clear(self):
        '''

        '''
        pass

    def copy(self):
        '''

        '''
        pass

    def fromkeys(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def pop(self):
        '''

        '''
        pass

    def popitem(self):
        '''

        '''
        pass

    def setdefault(self):
        '''

        '''
        pass

    def update(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class OrderedMeta:
    is_registered = None
    ''''''

    def mro(self):
        '''

        '''
        pass


class Panel:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def append(self, draw_func):
        '''

        '''
        pass

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_extended(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def prepend(self, draw_func):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def remove(self, draw_func):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class PoseBone:
    basename = None
    ''''''

    bl_rna = None
    ''''''

    center = None
    ''''''

    children = None
    ''''''

    children_recursive = None
    ''''''

    children_recursive_basename = None
    ''''''

    id_data = None
    ''''''

    length = None
    ''''''

    parent_recursive = None
    ''''''

    vector = None
    ''''''

    x_axis = None
    ''''''

    y_axis = None
    ''''''

    z_axis = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def parent_index(self, parent_test):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def translate(self, vec):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class PropertyGroup:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class RNAMeta:
    is_registered = None
    ''''''

    def mro(self):
        '''

        '''
        pass


class RNAMetaPropGroup:
    is_registered = None
    ''''''

    def mro(self):
        '''

        '''
        pass


class RenderEngine:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class ShaderNode:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def is_registered_node_type(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def poll(self, ntree):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Sound:
    bl_rna = None
    ''''''

    factory = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Text:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    users_logic = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def as_string(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def from_string(self, string):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Texture:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    users_material = None
    ''''''

    users_object_modifier = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class TextureNode:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def is_registered_node_type(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def poll(self, ntree):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class UIList:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def append(self, draw_func):
        '''

        '''
        pass

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_extended(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def prepend(self, draw_func):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def remove(self, draw_func):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class WindowManager:
    addon_filter = None
    ''''''

    addon_search = None
    ''''''

    addon_support = None
    ''''''

    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def fileselect_add(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def invoke_confirm(self):
        '''

        '''
        pass

    def invoke_popup(self):
        '''

        '''
        pass

    def invoke_props_dialog(self):
        '''

        '''
        pass

    def invoke_props_popup(self):
        '''

        '''
        pass

    def invoke_search_popup(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def modal_handler_add(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def piemenu_begin__internal(self):
        '''

        '''
        pass

    def piemenu_end__internal(self):
        '''

        '''
        pass

    def popup_menu(self, draw_func, title, icon):
        '''

        '''
        pass

    def popup_menu_pie(self, event, draw_func, title, icon):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def pupmenu_begin__internal(self):
        '''

        '''
        pass

    def pupmenu_end__internal(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


def ord_ind(i1, i2):
    '''

    '''

    pass
